# Yet another python project generator

Interactive python project generator. Use src layout.

## Usage

```
pip install yapygen
```

make sure `$PYTHON_HOME/Scripts` is on your path and

```
yap
```

or

```
python -m yapygen
```